==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/content/messages/pt/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Também visível para não-membros deste espaço)',
    '<strong>Delete</strong> content?' => '<strong>Eliminar</strong> conteúdo?',
    '<strong>Move</strong> content' => '<strong>Mover</strong> conteúdo',
    '<strong>Permalink</strong> to this post' => '<strong>Link</strong> para esta publicação',
    'Activated' => 'Activado',
    'Add a member to notify' => 'Adicionar uma pessoa para notificar',
    'Add tag...' => 'Adicionar etiqueta...',
    'Archived' => 'Arquivado',
    'Attach Files' => 'Anexar Ficheiros',
    'Back to stream' => 'Voltar ao stream',
    'Cancel' => 'Cancelar',
    'Cancel Edit' => 'Cancelar Edição',
    'Change to "Private"' => 'Mudar para "Privado"',
    'Change to "Public"' => 'Mudar para "Público"',
    'Comments are locked' => 'Comentários bloqueados',
    'Comments are unlocked' => 'Comentários desbloqueados',
    'Configure' => 'Configurar',
    'Confirm' => 'Confirmar',
    'Content' => 'Conteúdo',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Tag de conteúdo com contentcontainer_id inválido.',
    'Content has been moved to {spacename}' => 'O conteúdo foi movido para {spacename}',
    'Could not find requested content!' => 'Não foi possível encontrar o conteúdo solicitado!',
    'Created at:' => 'Creado em:',
    'Created by me' => 'Criado por mim',
    'Creation time' => 'Hora de criação',
    'Delete' => 'Eliminar',
    'Deleted' => 'Eliminada',
    'Edit' => 'Editar',
    'Enable' => 'Ativar',
    'Filter' => 'Filtro',
    'I\'m involved' => 'Onde estou envolvido',
    'Invalid content id given!' => 'Id de conteúdo fornecido inválido!',
    'Invalid request method!' => 'Método de solicitação inválido!',
    'Invalid space selection.' => 'Seleção de espaço inválida.',
    'Last update' => 'Última atualização',
    'Last updated {time}' => 'Última atualização {time}',
    'Load more' => 'Carregar mais',
    'Lock comments' => 'Bloquear comentários',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'O número máximo de itens afixados foi atingido!<br>Apenas podes afixar até {count} itens simultaneamente.',
    'Move content' => 'Mover conteúdo',
    'Move to archive' => 'Mover para arquivo',
    'New Updates Available!' => 'Novas Atualizações Disponíveis!',
    'No matches with your selected filters!' => 'Não há correspondências com os filtros selecionados!',
    'No tags found for the given query' => 'Não foram encontradas etiquetas para a pesquisa indicada',
    'None' => 'Nenhum',
    'Nothing here yet!' => 'Ainda não há nada aqui!',
    'Notify members' => 'Notificar membros',
    'Permalink' => 'Link',
    'Pin to top' => 'Afixar no topo',
    'Pinned' => 'Afixado',
    'Private' => 'Privado',
    'Public' => 'Público',
    'Select type...' => 'Seleciona o tipo...',
    'Specify who can see this content.' => 'Especificar quem pode ver este conteúdo.',
    'Submit' => 'Enviar',
    'Tag' => 'Etiqueta',
    'Target Space' => 'Espaço Alvo',
    'The author of this content is not allowed to create private content within the selected space.' => 'O autor deste conteúdo não está autorizado a criar conteúdo privado dentro do espaço selecionado.',
    'The author of this content is not allowed to create public content within the selected space.' => 'O autor deste conteúdo não está autorizado a criar conteúdo público dentro do espaço selecconado.',
    'The author of this content is not allowed to create this type of content within this space.' => 'O autor deste conteúdo não está autorizado a criar este tipo de conteúdo dentro deste espaço.',
    'The content can\'t be moved to its current space.' => 'O conteúdo não pode ser movido para o espaço atual.',
    'The content has been archived.' => 'O conteúdo foi arquivado.',
    'The content has been deleted.' => 'O conteúdo foi eliminado.',
    'The content has been unarchived.' => 'O conteúdo foi desarquivado.',
    'The given name is already in use.' => 'O nome fornecido já está a ser utilizado.',
    'The module {moduleName} is not enabled on the selected target space.' => 'O módulo {moduleName} não está ativado no espaço alvo selecionado.',
    'This action is disabled!' => 'Esta ação está desativada!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Este tipo de conteúdo não pode ser movido devido a uma definição de module-id não configurada.',
    'This content type can\'t be moved.' => 'Este conteúdo não pode ser movido.',
    'This space is archived.' => 'Este espaço está arquivado.',
    'This space is not visible!' => 'Este espaço não está visível!',
    'Topics' => 'Tópicos',
    'Turn off notifications' => 'Desligar notificações',
    'Turn on notifications' => 'Ligar notificações',
    'Unarchive' => 'Desarquivar',
    'Unlock comments' => 'Desbloquer comentários',
    'Unpin' => 'Desafixar',
    'Updated' => 'Atualizado',
    'Visible also to unregistered users' => 'Visível também para pessoas não registadas',
    'Visible only to you' => 'Visível apenas para ti',
    'Visible to all Space members' => 'Visível para todos os membros do Espaço',
    'Visible to all signed in users' => 'Visível para todas as pessoas conectadas',
    'Visible to friends of {displayName}' => 'Visível para amigos de {displayName}',
    'Visible to you and {displayName}' => 'Visível para ti e para {displayName}',
    'Visible to your friends' => 'Visível para os teus amigos',
    'With attachments' => 'Com anexos',
    'You cannot block the space owner!' => 'Não pode bloquear o responsável pelo espaço!',
    'You cannot block the user of the same container!' => 'Não pode bloquear o utilizador do mesmo contentor!',
    'You cannot block yourself!' => 'Não pode bloquear-se a si mesmo!',
    'You do not have the permission to move this content to the given space.' => 'Não tens permissão para mover este conteúdo para esse espaço.',
    'You do not have the permission to move this content.' => 'Não tens permissão para mover este conteúdo.',
    'Your last edit state has been saved!' => 'A tua última edição foi guardada!',
    'in' => 'em',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Cannot notify the author.' => '',
    'Create as draft' => '',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
    'Draft' => '',
    'Hidden' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Save as draft' => '',
    'Save scheduling' => '',
    'Schedule publication' => '',
    'Scheduled for {dateTime}' => '',
    'The content cannot be published!' => '',
    'The content has been successfully published.' => '',
];

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/content/messages/pt/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Também visível para não-membros deste espaço)',
    '<strong>Delete</strong> content?' => '<strong>Eliminar</strong> conteúdo?',
    '<strong>Move</strong> content' => '<strong>Mover</strong> conteúdo',
    '<strong>Permalink</strong> to this post' => '<strong>Link</strong> para esta publicação',
    'Add a member to notify' => 'Adicionar uma pessoa para notificar',
    'Add tag...' => 'Adicionar etiqueta...',
    'Archived' => 'Arquivado',
    'Attach Files' => 'Anexar Ficheiros',
    'Back to stream' => 'Voltar ao stream',
    'Cancel' => 'Cancelar',
    'Cancel Edit' => 'Cancelar Edição',
    'Change to "Private"' => 'Mudar para "Privado"',
    'Change to "Public"' => 'Mudar para "Público"',
    'Comments are locked' => 'Comentários bloqueados',
    'Comments are unlocked' => 'Comentários desbloqueados',
    'Configure' => 'Configurar',
    'Confirm' => 'Confirmar',
    'Content' => 'Conteúdo',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Tag de conteúdo com contentcontainer_id inválido.',
    'Content has been moved to {spacename}' => 'O conteúdo foi movido para {spacename}',
    'Could not find requested content!' => 'Não foi possível encontrar o conteúdo solicitado!',
    'Created at:' => 'Creado em:',
    'Created by me' => 'Criado por mim',
    'Creation time' => 'Hora de criação',
    'Delete' => 'Eliminar',
    'Deleted' => 'Eliminada',
    'Edit' => 'Editar',
    'Enable' => 'Ativar',
    'Enabled' => 'Activado',
    'Filter' => 'Filtro',
    'I\'m involved' => 'Onde estou envolvido',
    'Invalid content id given!' => 'Id de conteúdo fornecido inválido!',
    'Invalid request method!' => 'Método de solicitação inválido!',
    'Invalid space selection.' => 'Seleção de espaço inválida.',
    'Last update' => 'Última atualização',
    'Last updated {time}' => 'Última atualização {time}',
    'Load more' => 'Carregar mais',
    'Lock comments' => 'Bloquear comentários',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'O número máximo de itens afixados foi atingido!<br>Apenas podes afixar até {count} itens simultaneamente.',
    'Move content' => 'Mover conteúdo',
    'Move to archive' => 'Mover para arquivo',
    'New Updates Available!' => 'Novas Atualizações Disponíveis!',
    'No matches with your selected filters!' => 'Não há correspondências com os filtros selecionados!',
    'No tags found for the given query' => 'Não foram encontradas etiquetas para a pesquisa indicada',
    'None' => 'Nenhum',
    'Nothing here yet!' => 'Ainda não há nada aqui!',
    'Notify members' => 'Notificar membros',
    'Permalink' => 'Link',
    'Pin to top' => 'Afixar no topo',
    'Pinned' => 'Afixado',
    'Private' => 'Privado',
    'Public' => 'Público',
    'Select type...' => 'Seleciona o tipo...',
    'Specify who can see this content.' => 'Especificar quem pode ver este conteúdo.',
    'Submit' => 'Enviar',
    'Tag' => 'Etiqueta',
    'Target Space' => 'Espaço Alvo',
    'The author of this content is not allowed to create private content within the selected space.' => 'O autor deste conteúdo não está autorizado a criar conteúdo privado dentro do espaço selecionado.',
    'The author of this content is not allowed to create public content within the selected space.' => 'O autor deste conteúdo não está autorizado a criar conteúdo público dentro do espaço selecconado.',
    'The author of this content is not allowed to create this type of content within this space.' => 'O autor deste conteúdo não está autorizado a criar este tipo de conteúdo dentro deste espaço.',
    'The content can\'t be moved to its current space.' => 'O conteúdo não pode ser movido para o espaço atual.',
    'The content has been archived.' => 'O conteúdo foi arquivado.',
    'The content has been deleted.' => 'O conteúdo foi eliminado.',
    'The content has been unarchived.' => 'O conteúdo foi desarquivado.',
    'The given name is already in use.' => 'O nome fornecido já está a ser utilizado.',
    'The module {moduleName} is not enabled on the selected target space.' => 'O módulo {moduleName} não está ativado no espaço alvo selecionado.',
    'This action is disabled!' => 'Esta ação está desativada!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Este tipo de conteúdo não pode ser movido devido a uma definição de module-id não configurada.',
    'This content type can\'t be moved.' => 'Este conteúdo não pode ser movido.',
    'This space is archived.' => 'Este espaço está arquivado.',
    'This space is not visible!' => 'Este espaço não está visível!',
    'Topics' => 'Tópicos',
    'Turn off notifications' => 'Desligar notificações',
    'Turn on notifications' => 'Ligar notificações',
    'Unarchive' => 'Desarquivar',
    'Unlock comments' => 'Desbloquer comentários',
    'Unpin' => 'Desafixar',
    'Updated' => 'Atualizado',
    'Visible also to unregistered users' => 'Visível também para pessoas não registadas',
    'Visible only to you' => 'Visível apenas para ti',
    'Visible to all Space members' => 'Visível para todos os membros do Espaço',
    'Visible to all signed in users' => 'Visível para todas as pessoas conectadas',
    'Visible to friends of {displayName}' => 'Visível para amigos de {displayName}',
    'Visible to you and {displayName}' => 'Visível para ti e para {displayName}',
    'Visible to your friends' => 'Visível para os teus amigos',
    'With attachments' => 'Com anexos',
    'You cannot block the space owner!' => 'Não pode bloquear o responsável pelo espaço!',
    'You cannot block the user of the same container!' => 'Não pode bloquear o utilizador do mesmo contentor!',
    'You cannot block yourself!' => 'Não pode bloquear-se a si mesmo!',
    'You do not have the permission to move this content to the given space.' => 'Não tens permissão para mover este conteúdo para esse espaço.',
    'You do not have the permission to move this content.' => 'Não tens permissão para mover este conteúdo.',
    'Your last edit state has been saved!' => 'A tua última edição foi guardada!',
    'in' => 'em',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Advanced Content Search' => '',
    'Cannot notify the author.' => '',
    'Create as draft' => '',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
    'Draft' => '',
    'Hidden' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Save as draft' => '',
    'Save scheduling' => '',
    'Schedule publication' => '',
    'Scheduled for {dateTime}' => '',
    'The content cannot be published!' => '',
    'The content has been successfully published.' => '',
];
